==> jc-1.4.0.tar.gz: org/xml/sax/helpers/XMLReaderFactory.h <==
// public final class org.xml.sax.helpers.XMLReaderFactory

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 8ac5c68c5da499d0 org_xml_sax_helpers_XMLReaderFactory

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_xml_sax_helpers_XMLReaderFactory_H_
#define _JC_org_xml_sax_helpers_XMLReaderFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_ClassLoader$object;
struct _jc_java_lang_String$object;
struct _jc_org_xml_sax_XMLReader$object;

// Typedefs
typedef struct _jc_org_xml_sax_helpers_XMLReaderFactory$sub_refs	_jc_org_xml_sax_helpers_XMLReaderFactory$sub_refs;
typedef struct _jc_org_xml_sax_helpers_XMLReaderFactory$sub_nonrefs	_jc_org_xml_sax_helpers_XMLReaderFactory$sub_nonrefs;
typedef struct _jc_org_xml_sax_helpers_XMLReaderFactory$refs	_jc_org_xml_sax_helpers_XMLReaderFactory$refs;
typedef struct _jc_org_xml_sax_helpers_XMLReaderFactory$nonrefs	_jc_org_xml_sax_helpers_XMLReaderFactory$nonrefs;
typedef struct _jc_org_xml_sax_helpers_XMLReaderFactory$object	_jc_org_xml_sax_helpers_XMLReaderFactory$object;

typedef struct _jc_org_xml_sax_helpers_XMLReaderFactory$fields_struct	_jc_org_xml_sax_helpers_XMLReaderFactory$fields_struct;
typedef const struct _jc_org_xml_sax_helpers_XMLReaderFactory$vmethods	_jc_org_xml_sax_helpers_XMLReaderFactory$vmethods;
typedef const struct _jc_org_xml_sax_helpers_XMLReaderFactory$vtable	_jc_org_xml_sax_helpers_XMLReaderFactory$vtable;
typedef const struct _jc_org_xml_sax_helpers_XMLReaderFactory$vtype	_jc_org_xml_sax_helpers_XMLReaderFactory$vtype;

// Class fields structure
struct _jc_org_xml_sax_helpers_XMLReaderFactory$fields_struct {
	struct _jc_java_lang_String$object	*property;
};
extern _jc_org_xml_sax_helpers_XMLReaderFactory$fields_struct _jc_org_xml_sax_helpers_XMLReaderFactory$class_fields;

// Constructors
extern void _jc_org_xml_sax_helpers_XMLReaderFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_org_xml_sax_helpers_XMLReaderFactory$object *);

// Static methods
extern struct _jc_object *_jc_org_xml_sax_helpers_XMLReaderFactory$method$createXMLReader$e0ff9d267c7490ad(_jc_env *);
extern struct _jc_object *_jc_org_xml_sax_helpers_XMLReaderFactory$method$createXMLReader$9e5aeb72283b8ced(_jc_env *, struct _jc_java_lang_String$object *);
extern struct _jc_object *_jc_org_xml_sax_helpers_XMLReaderFactory$method$loadClass$19c650e69a071fef(_jc_env *, struct _jc_java_lang_ClassLoader$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_org_xml_sax_helpers_XMLReaderFactory$vmethods {
};

// Vtable
struct _jc_org_xml_sax_helpers_XMLReaderFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_xml_sax_helpers_XMLReaderFactory$vmethods	org_xml_sax_helpers_XMLReaderFactory;
};

// Vtype
struct _jc_org_xml_sax_helpers_XMLReaderFactory$vtype {
	_jc_type			type;
	_jc_org_xml_sax_helpers_XMLReaderFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_xml_sax_helpers_XMLReaderFactory$sub_refs {
};

// Reference instance fields (object)
struct _jc_org_xml_sax_helpers_XMLReaderFactory$refs {
    _jc_org_xml_sax_helpers_XMLReaderFactory$sub_refs	org_xml_sax_helpers_XMLReaderFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_xml_sax_helpers_XMLReaderFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_xml_sax_helpers_XMLReaderFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_xml_sax_helpers_XMLReaderFactory$sub_nonrefs	org_xml_sax_helpers_XMLReaderFactory;
};

// Object instance structure
struct _jc_org_xml_sax_helpers_XMLReaderFactory$object {
	_jc_org_xml_sax_helpers_XMLReaderFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_org_xml_sax_helpers_XMLReaderFactory$vtype	*vtype;
	_jc_org_xml_sax_helpers_XMLReaderFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_xml_sax_helpers_XMLReaderFactory$vtype _jc_org_xml_sax_helpers_XMLReaderFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_xml_sax_helpers_XMLReaderFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_xml_sax_helpers_XMLReaderFactory$class_object;

#endif	/* _JC_org_xml_sax_helpers_XMLReaderFactory_H_ */

==> jc-1.4.6.tar.gz: org/xml/sax/helpers/XMLReaderFactory.h <==
// public final class org.xml.sax.helpers.XMLReaderFactory

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8ac5c68c5da499d0 org_xml_sax_helpers_XMLReaderFactory

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_xml_sax_helpers_XMLReaderFactory_H_
#define _JC_org_xml_sax_helpers_XMLReaderFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_ClassLoader$object;
struct _jc_java_lang_String$object;
struct _jc_org_xml_sax_XMLReader$object;

// Typedefs
typedef struct _jc_org_xml_sax_helpers_XMLReaderFactory$sub_refs	_jc_org_xml_sax_helpers_XMLReaderFactory$sub_refs;
typedef struct _jc_org_xml_sax_helpers_XMLReaderFactory$sub_nonrefs	_jc_org_xml_sax_helpers_XMLReaderFactory$sub_nonrefs;
typedef struct _jc_org_xml_sax_helpers_XMLReaderFactory$refs	_jc_org_xml_sax_helpers_XMLReaderFactory$refs;
typedef struct _jc_org_xml_sax_helpers_XMLReaderFactory$nonrefs	_jc_org_xml_sax_helpers_XMLReaderFactory$nonrefs;
typedef struct _jc_org_xml_sax_helpers_XMLReaderFactory$object	_jc_org_xml_sax_helpers_XMLReaderFactory$object;

typedef struct _jc_org_xml_sax_helpers_XMLReaderFactory$fields_struct	_jc_org_xml_sax_helpers_XMLReaderFactory$fields_struct;
typedef const struct _jc_org_xml_sax_helpers_XMLReaderFactory$vmethods	_jc_org_xml_sax_helpers_XMLReaderFactory$vmethods;
typedef const struct _jc_org_xml_sax_helpers_XMLReaderFactory$vtable	_jc_org_xml_sax_helpers_XMLReaderFactory$vtable;
typedef const struct _jc_org_xml_sax_helpers_XMLReaderFactory$vtype	_jc_org_xml_sax_helpers_XMLReaderFactory$vtype;

// Class fields structure
struct _jc_org_xml_sax_helpers_XMLReaderFactory$fields_struct {
	struct _jc_java_lang_String$object	*property;
};
extern _jc_org_xml_sax_helpers_XMLReaderFactory$fields_struct _jc_org_xml_sax_helpers_XMLReaderFactory$class_fields;

// Constructors
extern void _jc_org_xml_sax_helpers_XMLReaderFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_org_xml_sax_helpers_XMLReaderFactory$object *) _JC_JCNI_ATTR;

// Static methods
extern struct _jc_object *_jc_org_xml_sax_helpers_XMLReaderFactory$method$createXMLReader$e0ff9d267c7490ad(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_org_xml_sax_helpers_XMLReaderFactory$method$createXMLReader$9e5aeb72283b8ced(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_org_xml_sax_helpers_XMLReaderFactory$method$loadClass$19c650e69a071fef(_jc_env *, struct _jc_java_lang_ClassLoader$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_org_xml_sax_helpers_XMLReaderFactory$vmethods {
};

// Vtable
struct _jc_org_xml_sax_helpers_XMLReaderFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_xml_sax_helpers_XMLReaderFactory$vmethods	org_xml_sax_helpers_XMLReaderFactory;
};

// Vtype
struct _jc_org_xml_sax_helpers_XMLReaderFactory$vtype {
	_jc_type			type;
	_jc_org_xml_sax_helpers_XMLReaderFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_xml_sax_helpers_XMLReaderFactory$sub_refs {
};

// Reference instance fields (object)
struct _jc_org_xml_sax_helpers_XMLReaderFactory$refs {
    _jc_org_xml_sax_helpers_XMLReaderFactory$sub_refs	org_xml_sax_helpers_XMLReaderFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_xml_sax_helpers_XMLReaderFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_xml_sax_helpers_XMLReaderFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_xml_sax_helpers_XMLReaderFactory$sub_nonrefs	org_xml_sax_helpers_XMLReaderFactory;
};

// Object instance structure
struct _jc_org_xml_sax_helpers_XMLReaderFactory$object {
	_jc_org_xml_sax_helpers_XMLReaderFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_org_xml_sax_helpers_XMLReaderFactory$vtype	*vtype;
	_jc_org_xml_sax_helpers_XMLReaderFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_xml_sax_helpers_XMLReaderFactory$vtype _jc_org_xml_sax_helpers_XMLReaderFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_xml_sax_helpers_XMLReaderFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_xml_sax_helpers_XMLReaderFactory$class_object;

#endif	/* _JC_org_xml_sax_helpers_XMLReaderFactory_H_ */
